#!/usr/bin/env python

from Card import *
from Deck import *
from Hand import *

def isFullHouse(H):
    """ Returns Trues if H represents a full house,
    i.e., 2 cards at one rank, and three cards with
    some other rank.
    
    PreC: H is a Hand
    """
    # Set up a list of the Card ranks
    H.sort()  # sorts the Cards based on rank
    r = []
    for C in H.cards:
        r.append(C.rank)
    B1 = r[0]==r[1] and r[1]==r[2] and r[3]==r[4]
    B2 = r[0]==r[1] and r[2]==r[3] and r[3]==r[4]
    return (B1 or B2)

def TwoPair(H):
    """ Returns Trues if H has two pair.
    
    PreC: H is a Hand
    """
    # Set up a list of the Card ranks
    H.sort()  # sorts the Cards based on rank
    r = []
    for C in H.cards:
        r.append(C.rank)
    B1 = r[0]==r[1] and r[2]==r[3] and r[4]!=r[0] and r[4]!=r[2]
    
    B2 = r[0]==r[1] and r[3]==r[4] and r[2]!=r[0] and r[4]!=r[2]
    
    B3 = r[1]==r[2] and r[3]==r[4] and r[0]!=r[1] and r[0]!=r[3]
    
    return (B1 or B2 or B3)

def pop_weakest(H):
    """
    Removes the weakest card in H
    PreC: H is a Hand
    """
    H.cards.pop(0)
        
    
def randomPokerHand():
    """Returns a reference to random Hand object that
    represents a 5-card poker hand.
    """
    D = Deck()
    D.shuffle()
    H = Hand('')
    for j in range(5):
        H.add_card(D.pop_card())
    return H

        

if __name__ == '__main__':
    
    count = 0
    N = 10000
    for k in range(N):
        H = randomPokerHand()
        if TwoPair(H):
            count+=1
    print '%1d Two-Pair Hands in %1d chances'%(count,N)

### Problem 4b
    print '\n\n Prob 4b\n'
    H = randomPokerHand()
    H.sort()
    print 'original hand...'
    print H
    pop_weakest(H)
    print  'after weakest card removed...'
    print H
    
### Problem 4c
    print '\n\n Prob 4c\n'
    # Create and shuffle a full deck
    D = Deck()
    D.shuffle()
    # Form a 5-card poker hand...
    H = Hand('')
    for k in range(5):
        c = D.pop_card()
        H.add_card(c)
    print H
    # Remove the two weakest cards
    pop_weakest(H)
    pop_weakest(H)
    print H
    # Replace with 2 cards from the deck...
    c = D.pop_card()
    H.add_card(c)
    c = D.pop_card()
    H.add_card(c)
    print H
    
    